#' @rdname is_windows
#' @export
assert_is_bsd <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_bsd, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_linux <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_linux, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_mac <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_mac, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx <- assert_is_mac

#' @rdname is_windows
#' @export
assert_is_osx_cheetah <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_cheetah, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_puma <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_puma, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_jaguar <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_jaguar, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_panther <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_panther, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_tiger <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_tiger, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_leopard <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_leopard, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_snow_leopard <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_snow_leopard, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_lion <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_lion, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_mountain_lion <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_mountain_lion, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_mavericks <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_mavericks, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_yosemite <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_yosemite, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_osx_el_capitan <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_osx_el_capitan, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_macos_sierra <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_macos_sierra, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_macos_high_sierra <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_macos_high_sierra, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_macos_mojave <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_macos_mojave, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_macos_catalina <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_macos_catalina, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_macos_big_sur <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_macos_big_sur, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_solaris <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_solaris, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_unix <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_unix, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_vista <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_vista, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_7 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_7, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_8 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_8, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_8.1 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_8.1, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_10 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_10, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_server_2008 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_server_2008, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_server_2008_r2 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_server_2008_r2, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_server_2012 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_server_2012, severity = severity)
}

#' @rdname is_windows
#' @export
assert_is_windows_server_2012_r2 <- function(severity = getOption("assertive.severity", "stop"))
{
  assert_engine(is_windows_server_2012_r2, severity = severity)
}
